Module lift_and_project

Module lift_and_project 

Structs

LiftAndProjectCuts
A (simplified) lift-and-project solver for binary (0–1) ILPs. This implementation generates disjunctive (integrality) cuts for each fractional binary variable, essentially enforcing that any fractional value is eliminated by adding an inequality that forces the variable to take on an integer value. These cuts are valid for all 0–1 points and, when added iteratively, drive the solution toward integrality.